extern crate xcb;

mod ewmh;

use comm;
use comm::Channel;
use config::Config;

pub fn wm(tx: &Channel, _config: &Config) {
    if let Ok((conn, screen_num)) = xcb::Connection::connect(None) {
        let ewmh = ewmh::connect(&conn, screen_num);

        let mut last_win = ewmh.get_active_window();
        comm::send(tx, "title", ewmh.get_window_name(last_win).as_ref());
        ewmh.watch(ewmh.root, true);
        ewmh.watch(last_win, true);
        conn.flush();

        loop {
            let event = conn.wait_for_event();
            match event {
                None => { break; }
                Some(event) => {
                    if event.response_type() == xcb::PROPERTY_NOTIFY {
                        let prop_event: &xcb::PropertyNotifyEvent = xcb::cast_event(&event);
                        if prop_event.atom() == ewmh._NET_ACTIVE_WINDOW {
                            let new_win = ewmh.get_active_window();
                            ewmh.watch(last_win, false);
                            ewmh.watch(new_win, true);
                            conn.flush();
                            last_win = new_win;
                            comm::send(tx, "title", ewmh.get_window_name(last_win).as_ref());
                        }
                        else if prop_event.atom() == ewmh._NET_WM_NAME {
                            comm::send(tx, "title", ewmh.get_window_name(last_win).as_ref());
                        }
                    }
                }
            }
        }
    } else {
        println!("Could not connect to X!");
    }
}

